@@ -95,7 +95,7 @@ public:
 	QString presetFile(const QString& sPreset);
 	void setPresetFile(const QString& sPreset, const QString& sPresetFile);
 	void removePreset(const QString& sPreset);
-	QStringList presetList();
+	const QStringList& presetList();
 
 	// Programs utility methods.
 	void loadPrograms(padthv1_programs *pPrograms);
@@ -128,6 +128,9 @@ protected:
 
 private:
 
+	// The presets list cache.
+	QStringList m_presetList;
+
 	// The singleton instance.
 	static padthv1_config *g_pSettings;
 };
